"""This module provides a minimal, uniform interface for creating chat objects backed by large language models (LLMs)."""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/helpers/01_llm.ipynb.

# %% auto 0
__all__ = ['LLM_MODELS', 'DEFAULT_TEMPERATURE', 'make_chat']

# %% ../../nbs/helpers/01_llm.ipynb 3
from lisette import Chat

LLM_MODELS = [
    "anthropic/claude-sonnet-4-5",
    "openai/gpt-5.1-codex",
]

DEFAULT_TEMPERATURE = 1

# %% ../../nbs/helpers/01_llm.ipynb 4
def make_chat(model, temp=DEFAULT_TEMPERATURE):
    """
    make_chat returns a callable.
    Calling it with a prompt returns plain text (str).

    Parameters
    ----------
    model : str
        Provider-qualified model identifier.
    temp : float, default=DEFAULT_TEMPERATURE
        Sampling temperature.

    Returns
    -------
    lisette.Chat
        A configured chat object.
    """
    return Chat(model, temp=temp)
