"""Tests to verify the package works across different platforms (Colab, Deepnote, Local)"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/99_platform_test.ipynb.

# %% auto 0
__all__ = []

# %% ../../nbs/99_platform_test.ipynb 2
import sys
import importlib.util
