# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/data401-nlp',
                'doc_host': 'https://su-dataAI.github.io',
                'git_url': 'https://github.com/su-dataAI/data401-nlp',
                'lib_path': 'data401_nlp'},
  'syms': { 'data401_nlp.helpers.env': {'data401_nlp.helpers.env.load_env': ('helpers/env.html#load_env', 'data401_nlp/helpers/env.py')},
            'data401_nlp.helpers.llm': {'data401_nlp.helpers.llm.make_chat': ('helpers/llm.html#make_chat', 'data401_nlp/helpers/llm.py')},
            'data401_nlp.helpers.spacy': { 'data401_nlp.helpers.spacy.ensure_spacy_model': ( 'helpers/spacy.html#ensure_spacy_model',
                                                                                             'data401_nlp/helpers/spacy.py'),
                                           'data401_nlp.helpers.spacy.list_installed_models': ( 'helpers/spacy.html#list_installed_models',
                                                                                                'data401_nlp/helpers/spacy.py')},
            'data401_nlp.helpers.submit': { 'data401_nlp.helpers.submit._can_use_dialoghelper': ( 'helpers/submit.html#_can_use_dialoghelper',
                                                                                                  'data401_nlp/helpers/submit.py'),
                                            'data401_nlp.helpers.submit._collect_answers_from_notebook': ( 'helpers/submit.html#_collect_answers_from_notebook',
                                                                                                           'data401_nlp/helpers/submit.py'),
                                            'data401_nlp.helpers.submit.collect_answers': ( 'helpers/submit.html#collect_answers',
                                                                                            'data401_nlp/helpers/submit.py'),
                                            'data401_nlp.helpers.submit.parse_answers': ( 'helpers/submit.html#parse_answers',
                                                                                          'data401_nlp/helpers/submit.py'),
                                            'data401_nlp.helpers.submit.review_answers': ( 'helpers/submit.html#review_answers',
                                                                                           'data401_nlp/helpers/submit.py'),
                                            'data401_nlp.helpers.submit.submit_answers': ( 'helpers/submit.html#submit_answers',
                                                                                           'data401_nlp/helpers/submit.py')},
            'data401_nlp.tests.platform': {}}}
